class Admin::WritingConferencesController < OrbitMemberController
  layout "member_plugin"
  include Admin::PersonalConferencesHelper

  before_action :set_writing_conference, only: [:show, :edit , :update, :destroy]
  before_action :set_plugin
  before_action :get_settings,:only => [:new, :edit, :setting]

  before_action :need_access_right
  before_action :allow_admin_only, :only => [:index, :setting]
  def update_setting
    setting_params = params.require(:writing_conference_setting).permit!
    setting_params[:display_fields_in_member_page] = [] if setting_params[:display_fields_in_member_page].nil?
    WritingConferenceSetting.update_all(setting_params)
    redirect_to admin_writing_conference_setting_path
  end
  def merge_process
    params['writing_conference_id'].each do |writing_conference_id|
        writing_conference_ids = writing_conference_id.split('/')
        writing_conferences = WritingConference.find(writing_conference_ids)
        member_ids = writing_conferences.collect(&:member_profile_id).uniq
        writing_conferences.each_with_index do |writing_conference,index1|
            if index1== 0
                writing_conference.member_profile_id = member_ids
                writing_conference.save!
            else
                writing_conference.delete
            end
        end
    end
    redirect_to :action=> 'index'
  end
  def merge
    @writing_conferences=WritingConference.sort_year_date.map{|value| value}.group_by{|v| [v[:paper_title],v[:conference_title]]}
    @writing_conferences.each do |key,value|
      if value.length<=1
        @writing_conferences.delete key
      end
    end
    if params['mode']!='simple'
      @writing_conferences.each do |key,value|
        @writing_conferences[key] = value.group_by{|v| [get_sponsor(v),get_author_type(v),get_paper_type(v),get_publication_date(v)]}
        @writing_conferences[key].each do |key1,value1|
          if value1.length<=1
            @writing_conferences[key].delete key1
          end
        end
        if @writing_conferences[key].length==0
            @writing_conferences.delete key
        end
      end
      
    end
  end

  def index
    @writing_conferences = WritingConference.sort_year_date.page(params[:page]).per(10)
  end

  def new
    @member = Array(MemberProfile.find_by(:uid=>params['uid'].to_s)) rescue nil
    @writing_conference = WritingConference.new

    if params[:desktop]
      render :layout => false
    end
  end

  def analysis_report
    role = params[:role_id]
    year_start = params[:year_start].to_i
    year_end = params[:year_end].to_i
    graph_by = params[:graph_by]

    @data = get_chart_data(year_start,year_end,role,params[:graph_by])

    render :layout => false
  end

  def download_excel
    year_start = params[:year_start].to_i
    year_end = params[:year_end].to_i
    @data = get_data_for_excel(year_start,year_end)
    respond_to do |format|
      format.xlsx {
        response.headers['Content-Disposition'] = 'attachment; filename="conference_papers.xlsx"'
      }
    end
  end

  def create

    if !conference_params['member_profile_id'].blank?

      @member = MemberProfile.find(conference_params['member_profile_id']) rescue nil
      @writing_conference = WritingConference.new(conference_params)
      @writing_conference.save

      if params[:desktop] == "true"
        render json: {"data" => get_paper_list}.to_json
      else
        redirect_to params['referer_url']
      end

    elsif !params[:author_members].blank?

      #params[:author_members].each do |author_member|

        conference_params['member_profile_id'] = params[:author_members]
        @writing_conference = WritingConference.new(conference_params)
        @writing_conference.save

        if params[:desktop] == "true"
          render json: {"data" => get_paper_list}.to_json
        end

      #end

      redirect_to params['referer_url']

    else

      conference_params['member_profile_id'] = User.find(current_user.id).member_profile_id

      @writing_conference = WritingConference.new(conference_params)
      @writing_conference.save

      if params[:desktop] == "true"
        render json: {"data" => get_paper_list}.to_json
      end

      redirect_to params['referer_url']

    end
    
  end

  def edit
    @member = get_member(@writing_conference)
    if params[:desktop]
      render :layout => false
    end
  end

  def update
    @member = get_member(@writing_conference)
    conference_params['member_profile_id'] = params[:author_members]
    @writing_conference.update_attributes(conference_params)
    @writing_conference.save
    if params[:desktop] == "true"
      render json: {"data" => get_paper_list}.to_json
    else
      redirect_to params['referer_url']
    end
  end

  def destroy
    @writing_conference.destroy
     respond_to do |format|     
      format.html { redirect_to(admin_writing_conferences_url) }
      # format.xml  { head :ok }
      format.js
      format.json {render json: {"success" => true}}
    end
  end

  def excel_format
    respond_to do |format|
      format.xlsx {
        response.headers['Content-Disposition'] = 'attachment; filename="conferences_format.xlsx"'
      }
    end
  end

  def import_from_excel
    workbook = RubyXL::Parser.parse(params["import_file"].tempfile)
    sheet = workbook[0]
    if sheet.count <= 503
      sheet.each_with_index do |row, i|
        next if i < 3
        user = User.where(:user_name => row.cells[0].value).first rescue nil
        if !user.nil?
          mp = user.member_profile
          import_this_writing_conference(row,mp)
        end
      end
      redirect_to admin_writing_conferences_url
    else
      redirect_to admin_writing_conferences_url(:error => "1")
    end
  end

  def toggle_hide
    if params[:ids]
      @writing_conferences = WritingConference.any_in(_id: params[:ids])

      @writing_conferences.each do |writing_conference|
        writing_conference.is_hidden = params[:disable]
        writing_conference.save
      end
    end

    render json: {"success"=>true}
  end

  def setting
  end

  def frontend_setting
    @member = MemberProfile.find_by(:uid=>params['uid'].to_s) rescue nil
    @intro = WritingConferenceIntro.find_by(:member_profile_id=>@member.id) rescue nil
    @intro = @intro.nil? ? WritingConferenceIntro.new({:member_profile_id=>@member.id}) : @intro
  end

  def update_frontend_setting
    @member = MemberProfile.find(intro_params['member_profile_id']) rescue nil
    @intro = WritingConferenceIntro.find_by(:member_profile_id=>@member.id) rescue nil
    @intro = @intro.nil? ? WritingConferenceIntro.new({:member_profile_id=>@member.id}) : @intro
    @intro.update_attributes(intro_params)
    @intro.save
    redirect_to URI.encode('/admin/members/'+@member.to_param+'/WritingConference')
  end

  def get_settings
    @paper_types = ConferencePaperType.all
    @paper_levels = ConferencePaperLevel.all
    @author_types = ConferenceAuthorType.all
  end

  def set_plugin
    @plugin = OrbitApp::Plugin::Registration.all.select{|plugin| plugin.app_name.eql? 'WritingConference'}.first
  end

  private

  def set_writing_conference
    path = request.path.split('/')
    if path.last.include? '-'
      uid = path[-1].split("-").last
      uid = uid.split("?").first
    else
      uid = path[-2].split("-").last
      uid = uid.split("?").first
    end
     @writing_conference = WritingConference.find_by(:uid => uid) rescue WritingConference.find(params[:id])
  end

  def conference_params
    params.require(:writing_conference).permit! rescue nil
  end

  def intro_params
    params.require(:writing_conference_intro).permit! rescue nil
  end
end